CheckVersionTask class

在启动时执行new-to-cur版本替换的任务。

迭代所有业务模块目录并应用:

  • 如果newcur都存在:将cur -> old,然后new -> cur
  • 如果只有new存在:将new -> cur
  • 如果存在old目录则删除

Constructors

CheckVersionTask()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

run() Future<void>
运行所有业务模块的版本检查任务。